Method: Quickl.build_command

Defined in:
lib/quickl.rb

.build_command(command) ⇒ Object

Builds command using the current builder.

The current command builder is considered consumed and removed as a side effect. A RuntimeError is raised if no builder is currently installed.

Returns the command itself.

This method is part of Quickl’s private interface.



46
47
48
49
50
51
52
53
54
# File 'lib/quickl.rb', line 46

def self.build_command(command)
  unless @builder
    raise "No command builder currently installed"
  else
    @builder.run(command)
    @builder = nil
    command
  end
end